==> haskell-interpolate-0.2.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-5hQ8KWj3NIj2WbXf0v9YkM
key: interpolate-0.2.0-5hQ8KWj3NIj2WbXf0v9YkM
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
abi: f158fb24de51b7e9b76eb214cf02c44a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-5hQ8KWj3NIj2WbXf0v9YkM
depends:
    base-4.10.1.0 haskell-src-meta-0.8.0.2-GKZAZaZEzJT2kmZZnGlE7J
    template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             haskell-src-meta-0.8.0.2-GKZAZaZEzJT2kmZZnGlE7J=82990162b74800a97255edc33f87f51b
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-JtoOrLe5o48JkKteT2XZIF
key: interpolate-0.2.0-JtoOrLe5o48JkKteT2XZIF
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
abi: 96a23c05ef58127bcaf588304218369b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-JtoOrLe5o48JkKteT2XZIF
depends:
    base-4.10.1.0 haskell-src-meta-0.8.0.2-KWwW3J9LJcM6fnpkJG5h5H
    template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             haskell-src-meta-0.8.0.2-KWwW3J9LJcM6fnpkJG5h5H=54c25ba3f84acc8068e2e4b0846ed752
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
